@@ -24,18 +24,16 @@ SSG_REF_URIS = {
     'dcid': 'not_officially_available',
     'disa': 'https://public.cyber.mil/stigs/cci/',
     'pcidss': 'https://www.pcisecuritystandards.org/documents/PCI_DSS_v3-2-1.pdf',
+    'pcidss4': 'https://docs-prv.pcisecuritystandards.org/PCI%20DSS/Standard/PCI-DSS-v4_0.pdf',
     'ospp': 'https://www.niap-ccevs.org/Profile/PP.cfm',
     'hipaa': 'https://www.gpo.gov/fdsys/pkg/CFR-2007-title45-vol1/pdf/CFR-2007-title45-vol1-chapA-subchapC.pdf',
+    'ism': 'https://www.cyber.gov.au/acsc/view-all-content/ism',
     'iso27001-2013': 'https://www.iso.org/standard/54534.html',
     'nerc-cip': 'https://www.nerc.com/pa/Stand/Standard%20Purpose%20Statement%20DL/US_Standard_One-Stop-Shop.xlsx',
     'stigid': 'https://public.cyber.mil/stigs/downloads/?_dl_facet_stigs=operating-systems%2Cunix-linux',
     'os-srg': 'https://public.cyber.mil/stigs/downloads/?_dl_facet_stigs=operating-systems%2Cgeneral-purpose-os',
     'app-srg': 'https://public.cyber.mil/stigs/downloads/?_dl_facet_stigs=application-servers',
     'stigref': 'https://public.cyber.mil/stigs/srg-stig-tools/',
-    # The following reference URIs were not defined in the XSLT constants
-    'ism': '',
-    'vmmsrg': '',
-    'vsrg': '',  # From the references, it looks like vsrg and vmmsrg are meant to be the same
 }
 
 product_directories = [
@@ -60,8 +58,8 @@ product_directories = [
     'uos20',
 ]
 
-JINJA_MACROS_DIRECTORY = os.path.join(os.path.dirname(os.path.dirname(
-    __file__)), "shared", "macros")
+JINJA_MACROS_DIRECTORY = os.path.abspath(os.path.join(os.path.dirname(os.path.dirname(
+    __file__)), "shared", "macros"))
 
 xml_version = """<?xml version="1.0" encoding="UTF-8"?>"""
 
@@ -75,9 +73,8 @@ xlink_namespace = "http://www.w3.org/1999/xlink"
 xhtml_namespace = "http://www.w3.org/1999/xhtml"
 xsi_namespace = "http://www.w3.org/2001/XMLSchema-instance"
 cat_namespace = "urn:oasis:names:tc:entity:xmlns:xml:catalog"
+sce_namespace = "http://open-scap.org/page/SCE_xccdf_stream"
 ocil_cs = "http://scap.nist.gov/schema/ocil/2"
-xccdf_header = xml_version + "<xccdf>"
-xccdf_footer = "</xccdf>"
 bash_system = "urn:xccdf:fix:script:sh"
 ansible_system = "urn:xccdf:fix:script:ansible"
 ignition_system = "urn:xccdf:fix:script:ignition"
@@ -85,7 +82,7 @@ kubernetes_system = "urn:xccdf:fix:script:kubernetes"
 blueprint_system = "urn:redhat:osbuild:blueprint"
 puppet_system = "urn:xccdf:fix:script:puppet"
 anaconda_system = "urn:redhat:anaconda:pre"
-cce_uri = "https://nvd.nist.gov/cce/index.cfm"
+cce_uri = "https://ncp.nist.gov/cce"
 stig_ns = "https://public.cyber.mil/stigs/srg-stig-tools/"
 cis_ns = "https://www.cisecurity.org/benchmark/red_hat_linux/"
 hipaa_ns = "https://www.gpo.gov/fdsys/pkg/CFR-2007-title45-vol1/pdf/CFR-2007-title45-vol1-chapA-subchapC.pdf"
@@ -140,6 +137,7 @@ PREFIX_TO_NS = {
     "cpe-dict": "http://cpe.mitre.org/dictionary/2.0",
     "cat": cat_namespace,
     "cpe-lang": "http://cpe.mitre.org/language/2.0",
+    "sce": sce_namespace,
 }
 
 FIX_TYPE_TO_SYSTEM = {
@@ -231,6 +229,7 @@ REF_PREFIX_MAP = {
     "nist": "NIST-800-53",
     "cui": "NIST-800-171",
     "pcidss": "PCI-DSS",
+    "pcidss4": "PCI-DSSv4",
     "cjis": "CJIS",
     "stigid": "DISA-STIG",
 }
@@ -256,6 +255,9 @@ REFERENCES = dict(
     pcidss=Reference(
         id="pcidss", name=REF_PREFIX_MAP["pcidss"], url="",
         regex_with_groups=r"Req-(\d+)(?:\.(\w+)(?:\.(\w+)(?:\.(\w+))?)?)?"),
+    pcidss4=Reference(
+        id="pcidss4", name=REF_PREFIX_MAP["pcidss4"], url="",
+        regex_with_groups=r"(\d+)(?:\.(\w+)(?:\.(\w+)(?:\.(\w+))?)?)?"),
     srg=Reference(
         id="srg", name="SRG", url="",
         regex_with_groups=r"(SRG-OS-\d+-GPOS-\d+)"
@@ -454,6 +456,8 @@ MAKEFILE_ID_TO_PRODUCT_MAP = {
     'eks': 'Amazon Elastic Kubernetes Service',
 }
 
+# References that can not be used with product-qualifiers
+GLOBAL_REFERENCES = ("srg", "disa", "cis-csc",)
 
 # Application constants
 DEFAULT_GID_MIN = 1000
@@ -465,7 +469,9 @@ DEFAULT_GRUB2_UEFI_BOOT_PATH = '/boot/grub2'
 DEFAULT_DCONF_GDM_DIR = 'gdm.d'
 DEFAULT_AIDE_CONF_PATH = '/etc/aide.conf'
 DEFAULT_AIDE_BIN_PATH = '/usr/sbin/aide'
+DEFAULT_FAILLOCK_PATH = '/var/run/faillock'
 DEFAULT_SSH_DISTRIBUTED_CONFIG = 'false'
 DEFAULT_PRODUCT = 'example'
 DEFAULT_CHRONY_CONF_PATH = '/etc/chrony.conf'
 DEFAULT_AUDISP_CONF_PATH = '/etc/audit'
+DEFAULT_SYSCTL_REMEDIATE_DROP_IN_FILE = 'false'
