@@ -1,15 +1,15 @@
 from __future__ import print_function
 
-import os
-import logging
-import subprocess
-from collections import namedtuple
 import functools
-import tarfile
-import tempfile
+import logging
+import os
 import re
 import shutil
+import subprocess
+import tarfile
+import tempfile
 import time
+from collections import namedtuple
 
 import ssg.yaml
 from ssg.build_cpe import ProductCPEs
@@ -21,6 +21,7 @@ from ssg.jinja import process_file_with_macros
 from ssg.products import product_yaml_path, load_product_yaml
 from ssg.rules import get_rule_dir_yaml, is_rule_dir
 from ssg.rule_yaml import parse_prodtype
+from ssg.utils import mkdir_p
 from ssg_test_suite.log import LogHelper
 
 import ssg.templates
@@ -159,7 +160,7 @@ class RuleResult(object):
 
     def __eq__(self, other):
         return (self.success == other.success
-                and tuple(self.passed_stages) == tuple(self.passed_stages))
+                and tuple(self.passed_stages) == tuple(other.passed_stages))
 
     def __lt__(self, other):
         return self.passed_stages_count > other.passed_stages_count
@@ -273,7 +274,7 @@ def get_product_context(product=None):
     product_yaml = dict()
     if product:
         yaml_path = product_yaml_path(SSG_ROOT, product)
-        product_yaml = load_product_yaml(yaml_path)
+        product_yaml.update(load_product_yaml(yaml_path))
 
     # We could run into a DocumentationNotComplete error when loading a
     # rule's YAML contents. However, because the test suite isn't executed
@@ -346,7 +347,7 @@ def create_tarball(test_content_by_rule_id):
     for rule_id, test_content in test_content_by_rule_id.items():
         short_rule_id = rule_id.replace(OSCAP_RULE, "")
         rule_dir = os.path.join(tmpdir, short_rule_id)
-        os.mkdir(rule_dir)
+        mkdir_p(rule_dir)
         write_rule_test_content_to_dir(rule_dir, test_content)
 
     try:
@@ -434,7 +435,7 @@ def select_templated_tests(test_dir_config, available_scenarios_basenames):
         msg = (
             "Test directory configuration contain inconsistencies: {allowed_and_denied} "
             "scenarios are both allowed and denied."
-            .format(test_dir_config=test_dir_config, allowed_and_denied=allowed_and_denied)
+            .format(allowed_and_denied=allowed_and_denied)
         )
         raise ValueError(msg)
     return available_scenarios_basenames
@@ -505,9 +506,8 @@ def load_test(absolute_path, rule_template, local_env_yaml):
     template_name = rule_template['name']
     template_vars = rule_template['vars']
     # Load template parameters and apply it to the test case.
-    maybe_template = ssg.templates.Template(_SHARED_TEMPLATES, template_name)
-    if maybe_template.looks_like_template():
-        maybe_template.load()
+    maybe_template = ssg.templates.Template.load_template(_SHARED_TEMPLATES, template_name)
+    if maybe_template is not None:
         template_parameters = maybe_template.preprocess(template_vars, "tests")
     else:
         raise ValueError("Rule uses template '{}' "
