@@ -1,18 +1,18 @@
 from __future__ import print_function
 
+import collections
+import contextlib
+import fnmatch
+import itertools
+import json
 import logging
+import math
 import os
-import shutil
 import os.path
 import re
+import shutil
 import subprocess
-import collections
-import json
-import fnmatch
 import tempfile
-import contextlib
-import itertools
-import math
 
 from ssg.constants import OSCAP_PROFILE, OSCAP_PROFILE_ALL_ID, OSCAP_RULE
 from ssg_test_suite import oscap
@@ -238,15 +238,31 @@ class RuleChecker(oscap.Checker):
     def _rule_matches_template_spec(self, template):
         return True
 
+    def _replace_platform_specific_packages(self, packages):
+        """ Returns the provided package list with names
+            updated according to the platform alternatives
+            listed in platform_package_overrides product field """
+        product_yaml = common.get_product_context(self.test_env.product)
+        platform_package_overrides = product_yaml["platform_package_overrides"]
+        packages_with_alternatives = set()
+        for package in packages:
+            if package in platform_package_overrides and platform_package_overrides[package]:
+                packages_with_alternatives.add(platform_package_overrides[package])
+            else:
+                packages_with_alternatives.add(package)
+        return packages_with_alternatives
+
     def _ensure_package_present_for_all_scenarios(
             self, test_content_by_rule_id):
         packages_required = set()
+
         for rule_test_content in test_content_by_rule_id.values():
             for s in rule_test_content.scenarios:
                 scenario_packages = s.script_params["packages"]
                 packages_required.update(scenario_packages)
         if packages_required:
-            common.install_packages(self.test_env, packages_required)
+            packages_to_install = self._replace_platform_specific_packages(packages_required)
+            common.install_packages(self.test_env, packages_to_install)
 
     def _prepare_environment(self, test_content_by_rule_id):
         try:
@@ -427,10 +443,13 @@ class RuleChecker(oscap.Checker):
 
     def _test_target(self):
         rules_to_test = self._get_rules_to_test()
+        source = self.rule_spec
+        if not self.rule_spec:
+            source = self.template_spec
         if not rules_to_test:
             logging.error("No tests found matching the {0}(s) '{1}'".format(
                 self.target_type,
-                ", ".join(self.rule_spec)))
+                ", ".join(source)))
             return
 
         test_content_by_rule_id = self._get_test_content_by_rule_id(
@@ -507,6 +526,19 @@ class RuleChecker(oscap.Checker):
         os.rename(temp_datastream, self.datastream)
         os.unlink(xslt_filename)
 
+    def _verify_rule_presence(self, rule_id, script, profiles):
+        for profile_id in profiles:
+            if profile_id == OSCAP_PROFILE_ALL_ID:
+                continue
+            rules_in_profile = xml_operations.get_all_rule_ids_in_profile(
+                self.datastream, self.benchmark_id, profile_id, logging)
+            short_rule_id = rule_id.replace(OSCAP_RULE, "")
+            if short_rule_id not in rules_in_profile:
+                logging.warning(
+                    "Rule {0} isn't part of profile {1} requested by "
+                    "script {2}.".format(rule_id, profile_id, script)
+                )
+
     def _check_rule_scenario(self, scenario, remote_rule_dir, rule_id, remediation_available):
         if not _apply_script(
                 remote_rule_dir, self.test_env, scenario.script):
@@ -525,6 +557,7 @@ class RuleChecker(oscap.Checker):
         if scenario.script_params['profiles']:
             profiles = get_viable_profiles(
                 scenario.script_params['profiles'], self.datastream, self.benchmark_id, scenario.script)
+            self._verify_rule_presence(rule_id, scenario.script, profiles)
         else:
             # Special case for combined mode when scenario.script_params['profiles']
             # is empty which means scenario is not applicable on given profile.
